@@ -28,10 +28,6 @@ import time
 import socket
 #from urllib3.exceptions import ConnectTimeoutError
 
-from ssl import create_default_context
-import certifi
-from elasticsearch import RequestsHttpConnection
-
 # This comment is necessary because pylint throws errors when using the elasticsearch API because it uses decorators.
 # pylint: disable=E1123
 # By default, queries will target to up to 10000 documents (maximum permitted by Elastic, without tweaking the legacy setup)
@@ -68,18 +64,14 @@ class Elasticsearchlib:
         ok = self.safe_ping()
         return ok, _es
 
-    def start_connection_secure(self, host, port, user, password, request_retries=3, total_retries=9):
+    def start_connection_secure(self, host, port, user, password, use_ssl=True, request_retries=3, total_retries=9):
         """
         :param request_retries: number of times a request will be retried before being dropped
         :param total_retries: number of consecutive retries before dropping the connection and throwing an Exception
         """
-        ssl_context = create_default_context(cafile=certifi.where())
         _es = Elasticsearch(hosts=[{'host': host, 'port': int(port)}],
                             http_auth=(user, password),
-                            #scheme="https",
-                            #connection_class=RequestsHttpConnection,
                             use_ssl=True,
-                            #ssl_context=ssl_context,
                             verify_certs=False)
         self.request_retries = request_retries
         self.total_retries = total_retries
